# $Id: Document.pm 38127 2012-11-05 14:29:46Z wsl $
# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/WS/ValidateCASv1/Document.pm $

use strict;
use warnings FATAL => 'all';
use utf8;

package Aselect::WS::ValidateCASv1::Document;

use Xyzzy::Document -self;

sub response {
	my $req = $self->req;

	my $uid = $req->uid;

	my $answer = defined $uid ? "yes\n$uid\n" : "no\n\n";

	my $res = new Xyzzy::Response(content => $answer);
	$res->mimetype('text/plain', charset => 'UTF-8');
	return $res;
}
